---
title: Defense system triggers
contributors: 
    - Avigail Stokar-Avihail
---

# How anti-phage systems sense invading phages
Upon phage infection, the bacterial immune system senses a specific phage component or modification that the phage exerts on the cell to elicit the bacterial immune response. Understanding how bacteria sense phage infection is a fundamental question, which remains unanswered for the majority of recently discovered immune systems. There are dozens of cases in which the mechanism of immunity has been elucidated, but the phage trigger remains elusive. Understanding how antiphage systems are activated is key for a full understanding of bacterial immunity and for repurposing them as molecular tools as has been done for restriction enzymes and CRISPR-Cas. 

## Diversity
Various determinants of the phage can elicit bacterial immunity either in a direct or indirect manner. The most common and well known prokaryotic anti-phage systems, restriction enzymes and CRISPR-Cas, recognize and cleave phage DNA or RNA. More recently, a CBASS system has been found to directly bind to a structured phage RNA that triggers immune activation1. In other cases, defense systems are activated by protein coding phage genes. In some cases, the phage protein is directly sensed by the defense systems, as has been beautifully demonstrated for the Avs systems that directly bind either the phage terminase or portal protein2. In other cases, the phage protein can be sensed indirectly by the defense system, for example by detecting its activity in the cell. Such an indirect mechanism has been found for example in the case of some retron defense systems that are triggered by phage tampering with the RecBCD protein complex3,4. For a comprehensive coverage of all recent phage detection mechanisms the recent review by Huiting and Bondy-Denomy5 is highly recommended. 

## Method of discovery:
The main method used to pinpoint phage components that trigger a specific defense system of interest has been through a simple classic genetics approach, whereby mutant phages that overcome the defense system are examined. Such mutants often occur spontaneously and can thus be selected for by simply picking phage plaques that are able to form on a lawn of bacteria expressing the defense system4,5. The hypothesis is that the phage mutant escapes bacterial immunity due to a mutation in the component sensed by the system. Thus, sequencing these phage mutants and identification of the mutated locus is the first required step. To validate that the mutated phage component is indeed the actual trigger of the defense system, follow up experiments are required. For example, in some cases expression of this phage component without any other phage genes is sufficient to elicit the activity of bacterial immune system. This approach was used to identify Borvo activation by expression of the phage DNA polymerase4, Dazbog activation by expression of a phage DNA methylase4, retron activation by either phage SSB proteins4 or by proteins that inhibit the host RecBCD3, CapRel triggering by the phage Capsid protein6 and many more5. Additional biochemical pulldown assays can be used to assess binding of the defense system to the suspected phage trigger. 
One major caveat in the above approach is that in some cases mutant phages that escape the immune system cannot be isolated. This can occur for example if the defense system senses a general fold of a highly conserved and essential phage protein. In this case a simple mutation in the protein will not suffice for the phage to escape detection. In such cases, an alternative approach can be used that does not rely on isolation of escape mutants. An overexpression library of all phage genes can be co-expressed with the defense system of interest, and then assayed for immune activation. This approach was successfully applied for identification phage components that trigger diverse Avs systems2. 

## General concepts: 
Although much is still unknown regarding how bacterial immune systems sense phage infection, by combining the data observed so far, several general concepts in immune sensing are beginning to come to light. First, mechanistically diverse immune systems appear to have converged to sense common conserved phage components4.  These include the phage core replication machinery, host takeover machinery and structural components. Second, several studies have found cases in which defense occurs in a multi-layered fashion, whereby a second system is activated when the first one fails3,7,8. Research in upcoming years is expected to reveal additional guiding principles in the ways bacteria detect phages. 

## References:
1.	Banh D V, Roberts C G, Amador A M, Brady S F, & Marraffini L A. (2023) Bacterial cGAS senses a viral RNA to initiate immunity. bioRxiv 2023.03.07.531596 doi:10.1101/2023.03.07.531596.
2.	Gao L A, Wilkinson M E, Strecker J, Makarova K S, Macrae R K, Koonin E V, & Zhang F. (2022) Prokaryotic innate immunity through pattern recognition of conserved viral  proteins. Science 377: eabm4096.
3.	Millman A, Bernheim A, Stokar-Avihail A, Fedorenko T, Voichek M, Leavitt A, Oppenheimer-Shaanan Y, & Sorek R. (2020) Bacterial Retrons Function In Anti-Phage Defense. Cell 183: 1551–1561.
4.	Stokar-Avihail A, Fedorenko T, Hör J, Garb J, Leavitt A, Millman A, Shulman G, Wojtania N, Melamed S, Amitai G, & Sorek R. (2023) Discovery of phage determinants that confer sensitivity to bacterial immune systems. Cell 186: 1863-1876.e16.
5.	Huiting E & Bondy-Denomy J. (2023) Defining the expanding mechanisms of phage-mediated activation of bacterial immunity. Curr. Opin. Microbiol. 74: 102325.
6.	Zhang T, Tamman H, Coppieters ’t Wallant K, Kurata T, LeRoux M, Srikant S, Brodiazhenko T, Cepauskas A, Talavera A, Martens C, Atkinson G C, Hauryliuk V, Garcia-Pino A, & Laub M T. (2022) Direct activation of a bacterial innate immune system by a viral capsid protein. Nature 612: 132–140.
7.	Rousset F, Depardieu F, Miele S, Dowding J, Laval A-L, Lieberman E, Garry D, Rocha E P C, Bernheim A, & Bikard D. (2022) Phages and their satellites encode hotspots of antiviral systems. Cell Host Microbe 30: 740–753.
8.	Penner M, Morad I, Snyder L, & Kaufmann G. (1995) Phage T4-coded Stp: Double-edged effector of coupled DNA and tRNA-restriction systems. J. Mol. Biol. 249: 857–68.

